﻿--[[--------------------------------------------------------------------------------------------------------------------   
  -- BGL-PBR -- Pet Battle Round counter display
  Copyright © 2016-2019 Campaign Builders Guild, Inc.
  <www.cbguild.com>

  License: GNU General Public License version 3 (or higher) 

  This file is part of BGL-PBR, a World of Warcraft Addon.

    BGL-PBR is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    BGL-PBR is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with BGL-PBR.  If not, see <http://www.gnu.org/licenses/>.

--]]--------------------------------------------------------------------------------------------------------------------

------------------------------------------------------------------------------------------------------------------------
-- Variables
------------------------------------------------------------------------------------------------------------------------

local BGL_PBR_INTERNAL_VERSION = "8.1"
BGL_PBR_ADDON_NAME = "BGL-PBR"

local FOLDER_NAME, private = ...
local L = private.L

BGL_PBR_PET_BATTLE = L['PET_BATTLE']
BGL_PBR_NEXT_ROUND_ALLCAP = L['NEXT_ROUND_ALLCAP']

bglPBRData = {
	round = 0,
}

------------------------------------------------------------------------------------------------------------------------
-- Event Handlers
------------------------------------------------------------------------------------------------------------------------

function bglPBROpen(enable)
  if bglPBRFrame then
    if enable and enable == true then
      bglPBRFrame:Show()
    else
      bglPBRFrame:Hide()
    end
  end
end

function bglPBR_OnLoad(self)
  self:UnregisterEvent("ADDON_LOADED")
  self:RegisterEvent("PLAYER_ENTERING_WORLD")
  self:RegisterEvent("PET_BATTLE_OPENING_START")
  self:RegisterEvent("PET_BATTLE_FINAL_ROUND")
  self:RegisterEvent("PET_BATTLE_CLOSE")
  self:RegisterEvent("PET_BATTLE_OVER")
  self:RegisterEvent("PET_BATTLE_CAPTURED")
  self:RegisterEvent("PET_BATTLE_PET_CHANGED")
  self:RegisterEvent("PET_BATTLE_PET_ROUND_RESULTS")
  self:SetScript("OnEvent",bglPBR_OnEvent)
end

function bglPBR_OnEvent(self, event, ...)
  if event == "PLAYER_ENTERING_WORLD" then
    bglPBROpen(false)
  elseif event == "PET_BATTLE_OPENING_START" then
    bglPBROpen(false) -- suppress until decremented by PET_BATTLE_PET_CHANGED
    bglPBRData.round = 1
  elseif 
    event == "PET_BATTLE_CLOSE" 
    or event == "PET_BATTLE_OVER"
    or event == "PET_BATTLE_CAPTURED"
    or event == "PET_BATTLE_FINAL_ROUND"
  then
    bglPBROpen(false)
  elseif 
    event == "PET_BATTLE_PET_ROUND_RESULTS"
  then
    bglPBRData.round = bglPBRData.round + 1
  elseif event == "PET_BATTLE_PET_CHANGED" then
    local team, _ = ...

    if team == 2 then
      bglPBRData.round = bglPBRData.round - 1
    end

    if bglPBRData.round == 1 then
      bglPBROpen(true)
    end
  end
end
